@@ -1,6 +1,7 @@
 """
 Classes for querying which lines have changed based on a diff.
 """
+
 import fnmatch
 import glob
 import os
@@ -164,18 +165,31 @@ class GitDiffReporter(BaseDiffReporter):
 
         # Get the diff dictionary
         diff_dict = self._git_diff()
-
         # include untracked files
         if self._include_untracked:
             for path in self._git_diff_tool.untracked():
-                with open(path) as file_handle:
-                    num_lines = len(file_handle.readlines())
+                if not self._validate_path_to_diff(path):
+                    continue
+
+                num_lines = self._get_file_lines(path)
                 diff_dict[path] = list(range(1, num_lines + 1))
 
         # Return the changed file paths (dict keys)
         # in alphabetical order
         return sorted(diff_dict.keys(), key=lambda x: x.lower())
 
+    @staticmethod
+    def _get_file_lines(path):
+        """
+        Return the number of lines in a file.
+        """
+
+        try:
+            with open(path, encoding="utf-8") as file_handle:
+                return len(file_handle.readlines())
+        except UnicodeDecodeError:
+            return 0
+
     def lines_changed(self, src_path):
         """
         See base class docstring.
@@ -216,7 +230,6 @@ class GitDiffReporter(BaseDiffReporter):
 
         # If we do not have a cached result, execute `git diff`
         if self._diff_dict is None:
-
             result_dict = {}
 
             for diff_str in self._get_included_diff_results():
@@ -224,26 +237,19 @@ class GitDiffReporter(BaseDiffReporter):
                 diff_dict = self._parse_diff_str(diff_str)
 
                 for src_path, (added_lines, deleted_lines) in diff_dict.items():
-                    if self._is_path_excluded(src_path):
+                    if not self._validate_path_to_diff(src_path):
                         continue
-                    # If no _supported_extensions provided, or extension present: process
-                    _, extension = os.path.splitext(src_path)
-                    extension = extension[1:].lower()
-                    # 'not self._supported_extensions' tests for both None and empty list []
-                    if (
-                        not self._supported_extensions
-                        or extension in self._supported_extensions
-                    ):
-                        # Remove any lines from the dict that have been deleted
-                        # Include any lines that have been added
-                        result_dict[src_path] = [
-                            line
-                            for line in result_dict.get(src_path, [])
-                            if line not in deleted_lines
-                        ] + added_lines
+
+                    # Remove any lines from the dict that have been deleted
+                    # Include any lines that have been added
+                    result_dict[src_path] = [
+                        line
+                        for line in result_dict.get(src_path, [])
+                        if line not in deleted_lines
+                    ] + added_lines
 
             # Eliminate repeats and order line numbers
-            for (src_path, lines) in result_dict.items():
+            for src_path, lines in result_dict.items():
                 result_dict[src_path] = self._unique_ordered_lines(lines)
 
             # Store the resulting dict
@@ -252,6 +258,29 @@ class GitDiffReporter(BaseDiffReporter):
         # Return the diff cache
         return self._diff_dict
 
+    def _validate_path_to_diff(self, src_path: str) -> bool:
+        """
+        Validate if a path should be included in the diff.
+
+        Returns True if the path should be included, otherwise False.
+
+        A path should be excluded if:
+        - If the path is excluded
+        - If the path has an extension that is not supported
+        """
+
+        if self._is_path_excluded(src_path):
+            return False
+
+        # If no _supported_extensions provided, or extension present: process
+        _, extension = os.path.splitext(src_path)
+        extension = extension[1:].lower()
+
+        if self._supported_extensions and extension not in self._supported_extensions:
+            return False
+
+        return True
+
     # Regular expressions used to parse the diff output
     SRC_FILE_RE = re.compile(r'^diff --git "?a/.*"? "?b/([^\n"]*)"?')
     MERGE_CONFLICT_RE = re.compile(r"^diff --cc ([^\n]*)")
@@ -274,8 +303,7 @@ class GitDiffReporter(BaseDiffReporter):
 
         # Parse the diff string into sections by source file
         sections_dict = self._parse_source_sections(diff_str)
-        for (src_path, diff_lines) in sections_dict.items():
-
+        for src_path, diff_lines in sections_dict.items():
             # Parse the hunk information for the source file
             # to determine lines changed for the source file
             diff_dict[src_path] = self._parse_lines(diff_lines)
@@ -304,12 +332,10 @@ class GitDiffReporter(BaseDiffReporter):
 
         # Parse the diff string into sections by source file
         for line in diff_str.split("\n"):
-
             # If the line starts with "diff --git"
             # or "diff --cc" (in the case of a merge conflict)
             # then it is the start of a new source file
             if line.startswith("diff --git") or line.startswith("diff --cc"):
-
                 # Retrieve the name of the source file
                 src_path = self._parse_source_line(line)
 
@@ -324,11 +350,9 @@ class GitDiffReporter(BaseDiffReporter):
             # Every other line is stored in the dictionary for this source file
             # once we find a hunk section
             else:
-
                 # Only add lines if we're in a hunk section
                 # (ignore index and files changed lines)
                 if found_hunk or line.startswith("@@"):
-
                     # Remember that we found a hunk
                     found_hunk = True
 
@@ -362,7 +386,6 @@ class GitDiffReporter(BaseDiffReporter):
         current_line_old = None
 
         for line in diff_lines:
-
             # If this is the start of the hunk definition, retrieve
             # the starting line number
             if line.startswith("@@"):
@@ -371,12 +394,10 @@ class GitDiffReporter(BaseDiffReporter):
 
             # This is an added/modified line, so store the line number
             elif line.startswith("+"):
-
                 # Since we parse for source file sections before
                 # calling this method, we're guaranteed to have a source
                 # file specified.  We check anyway just to be safe.
                 if current_line_new is not None:
-
                     # Store the added line
                     added_lines.append(current_line_new)
 
@@ -386,12 +407,10 @@ class GitDiffReporter(BaseDiffReporter):
             # This is a deleted line that does not exist in the final
             # version, so skip it
             elif line.startswith("-"):
-
                 # Since we parse for source file sections before
                 # calling this method, we're guaranteed to have a source
                 # file specified.  We check anyway just to be safe.
                 if current_line_old is not None:
-
                     # Store the deleted line
                     deleted_lines.append(current_line_old)
 
@@ -458,17 +477,15 @@ class GitDiffReporter(BaseDiffReporter):
         # be the hunk information, and any additional components
         # are excerpts from the code.
         if len(components) >= 2:
-
             hunk_info = components[1]
             groups = self.HUNK_LINE_RE.findall(hunk_info)
 
             if len(groups) == 1:
-
                 try:
                     return int(groups[0])
 
                 except ValueError:
-                    msg = "Could not parse '{}' as a line number".format(groups[0])
+                    msg = f"Could not parse '{groups[0]}' as a line number"
                     raise GitDiffError(msg)
 
             else:
