@@ -24,7 +24,7 @@ class XmlCoverageReporter(BaseViolationReporter):
     Query information from a Cobertura|Clover|JaCoCo XML coverage report.
     """
 
-    def __init__(self, xml_roots, src_roots=None):
+    def __init__(self, xml_roots, src_roots=None, expand_coverage_report=False):
         """
         Load the XML coverage report represented
         by the cElementTree with root element `xml_root`.
@@ -41,6 +41,7 @@ class XmlCoverageReporter(BaseViolationReporter):
         self._xml_cache = [{} for i in range(len(xml_roots))]
 
         self._src_roots = src_roots or [""]
+        self._expand_coverage_report = expand_coverage_report
 
     def _get_xml_classes(self, xml_document):
         """
@@ -216,6 +217,28 @@ class XmlCoverageReporter(BaseViolationReporter):
                 if line_nodes is None:
                     continue
 
+                # Expand coverage report with not reported lines
+                if self._expand_coverage_report:
+                    reported_line_hits = {}
+                    for line in line_nodes:
+                        reported_line_hits[int(line.get(_number))] = int(
+                            line.get(_hits, 0)
+                        )
+                    if reported_line_hits:
+                        last_hit_number = 0
+                        for line_number in range(
+                            min(reported_line_hits.keys()),
+                            max(reported_line_hits.keys()),
+                        ):
+                            if line_number in reported_line_hits:
+                                last_hit_number = reported_line_hits[line_number]
+                            else:
+                                # This is an unreported line.
+                                # We add it with the previous line hit score
+                                line_nodes.append(
+                                    {_hits: last_hit_number, _number: line_number}
+                                )
+
                 # First case, need to define violations initially
                 if violations is None:
                     violations = {
@@ -264,7 +287,7 @@ class XmlCoverageReporter(BaseViolationReporter):
 
 class LcovCoverageReporter(BaseViolationReporter):
     """
-    Query information from a Cobertura|Clover|JaCoCo XML coverage report.
+    Query information from a LCov coverage report.
     """
 
     def __init__(self, lcov_roots, src_roots=None):
@@ -288,7 +311,7 @@ class LcovCoverageReporter(BaseViolationReporter):
         File format: https://ltp.sourceforge.net/coverage/lcov/geninfo.1.php
         """
         lcov_report = defaultdict(dict)
-        lcov = open(lcov_file, "r")
+        lcov = open(lcov_file)
         while True:
             line = lcov.readline()
             if not line:
@@ -297,7 +320,7 @@ class LcovCoverageReporter(BaseViolationReporter):
             # we're only interested in file name and line coverage
             if directive == "SF":
                 # SF:<absolute path to the source file>
-                source_file = content
+                source_file = util.to_unix_path(GitPathTool.relative_path(content))
                 continue
             elif directive == "DA":
                 # DA:<line number>,<execution count>[,<checksum>]
@@ -324,6 +347,7 @@ class LcovCoverageReporter(BaseViolationReporter):
                 "BRF",
                 "BRH",
                 "BRDA",
+                "VER",
             ]:
                 # these are valid lines, but not we don't need them
                 continue
@@ -365,10 +389,11 @@ class LcovCoverageReporter(BaseViolationReporter):
 
             # Loop through the files that contain the xml roots
             for lcov_document in self._lcov_roots:
-
                 src_search_path = src_abs_path
                 if src_search_path not in lcov_document:
                     src_search_path = src_rel_path
+                if src_search_path not in lcov_document:
+                    continue
 
                 # First case, need to define violations initially
                 if violations is None:
@@ -475,6 +500,18 @@ jshint_driver = RegexBasedDriver(
     command_to_check_install=["jshint", "-v"],
 )
 
+shellcheck_driver = RegexBasedDriver(
+    name="shellcheck",
+    supported_extensions=["sh"],
+    # Use gcc format to ease violations parsing
+    command=["shellcheck", "-f", "gcc"],
+    expression=r"^([^:]+):(\d+):(\d+: .*)$",
+    command_to_check_install=["shellcheck", "-V"],
+    # shellcheck exit code is 1 if there are violations
+    # https://www.shellcheck.net/wiki/Integration#exit-codes
+    exit_codes=[0, 1],
+)
+
 
 class EslintDriver(RegexBasedDriver):
     def __init__(self):
@@ -609,7 +646,6 @@ class PylintDriver(QualityDriver):
                 # Ignore any line that isn't matched
                 # (for example, snippets from the source code)
                 if match is not None:
-
                     (
                         pylint_src_path,
                         line_number,
@@ -692,7 +728,6 @@ class CppcheckDriver(QualityDriver):
                 # Ignore any line that isn't matched
                 # (for example, snippets from the source code)
                 if match is not None:
-
                     (cppcheck_src_path, line_number, message) = match.groups()
 
                     violation = Violation(int(line_number), message)
