@@ -169,7 +169,6 @@ class BaseReportGeneratorTest:
 
 
 class TestSimpleReportGenerator(BaseReportGeneratorTest):
-
     REPORT_GENERATOR_CLASS = SimpleReportGenerator
 
     @pytest.fixture(autouse=True)
@@ -264,7 +263,6 @@ class TestTemplateReportGenerator(BaseReportGeneratorTest):
 
 
 class TestJsonReportGenerator(BaseReportGeneratorTest):
-
     REPORT_GENERATOR_CLASS = JsonReportGenerator
 
     def assert_report(self, expected):
@@ -282,11 +280,13 @@ class TestJsonReportGenerator(BaseReportGeneratorTest):
                 "diff_name": "main",
                 "src_stats": {
                     "file1.py": {
+                        "covered_lines": [2, 3, 4, 15],
                         "percent_covered": 66.66666666666667,
                         "violation_lines": [10, 11],
                         "violations": [[10, None], [11, None]],
                     },
                     "subdir/file2.py": {
+                        "covered_lines": [2, 3, 4, 15],
                         "percent_covered": 66.66666666666667,
                         "violation_lines": [10, 11],
                         "violations": [[10, None], [11, None]],
@@ -314,6 +314,7 @@ class TestJsonReportGenerator(BaseReportGeneratorTest):
                 "diff_name": "main",
                 "src_stats": {
                     "file.py": {
+                        "covered_lines": [2],
                         "percent_covered": 100.0,
                         "violation_lines": [],
                         "violations": [],
@@ -348,7 +349,6 @@ class TestJsonReportGenerator(BaseReportGeneratorTest):
 
 
 class TestStringReportGenerator(BaseReportGeneratorTest):
-
     REPORT_GENERATOR_CLASS = StringReportGenerator
 
     def test_generate_report(self):
@@ -417,7 +417,6 @@ class TestStringReportGenerator(BaseReportGeneratorTest):
 
 
 class TestHtmlReportGenerator(BaseReportGeneratorTest):
-
     REPORT_GENERATOR_CLASS = HtmlReportGenerator
 
     def test_generate_report(self):
@@ -457,7 +456,6 @@ class TestHtmlReportGenerator(BaseReportGeneratorTest):
 
 
 class TestMarkdownReportGenerator(BaseReportGeneratorTest):
-
     REPORT_GENERATOR_CLASS = MarkdownReportGenerator
 
     def test_generate_report(self):
@@ -534,7 +532,6 @@ class TestMarkdownReportGenerator(BaseReportGeneratorTest):
         self.assert_report(expected)
 
     def test_multiple_snippets(self):
-
         self.use_default_values()
 
         # Have the snippet loader always report
